@@ -71,30 +71,6 @@ if (identical(Sys.getenv("NOT_CRAN"), "true")) {
 
     df_alta <- data.frame(lon = c(-122.974, -123.0042), lat = c(50.1232, 50.1035))
     p <- ggplot(df_alta, aes(lon, lat)) + geom_spatial_point(crs = 4326)
-    expect_doppelganger_extra(
-      "hillshade",
-      p +
-        annotation_map_tile(type = "hillshade", alpha = 1)
-    )
-
-    expect_doppelganger_extra(
-      "hillshade with alpha",
-      p +
-        annotation_map_tile(type = "hillshade", alpha = 0.5)
-    )
-    expect_doppelganger_extra(
-      "projected hillshade",
-      p +
-        annotation_map_tile(type = "hillshade", alpha = 1) +
-        coord_sf(crs = 26910)
-    )
-    expect_doppelganger_extra(
-      "projected hillshade w/alpha",
-      p +
-        annotation_map_tile(type = "hillshade", alpha = 0.5) +
-        coord_sf(crs = 26910)
-    )
-
 
     expect_doppelganger_extra(
       "rgb tile",
